// importing necessary libraries
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
// adding constant variables
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //expliquer
  const title = 'MEN WORLDS HEIGHT';
  
  const xValue = d => d.Year; //display dates sur x axis
  const xAxisLabel = 'Year';

  const yValue = d => d.Height;
  const yAxisLabel = 'Height';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  //x and y values
  const xScale = scaleTime()

    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //rounds the value near to it
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  // generates line
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://gist.githubusercontent.com/saidhiraj16/f007eba20b98222d9aeb95d8bcdb8a50/raw/b34c70a3ff1c80845372ffc047a3eaffc0cf21c1/WorldHeight.csv')
  .then(data => {
  
    data.forEach(d => {
    	d.Height = +d.Height;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  })